@@ -24,13 +24,25 @@ class KinesisLogStreamHandler(logging.StreamHandler):
         try:
             session = boto3.Session()
             if 'KINESIS_ENDPOINT_URL' in os.environ:
-                self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+                self.datastream = session.client('kinesis',\
+                    endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
             else:
                 self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
 
         self.stream_name = os.environ['LOG_STREAMNAME']
+        try:
+            self.datastream.create_stream(
+                StreamName=self.stream_name,
+                ShardCount=1,
+                StreamModeDetails={
+                    'StreamMode': 'PROVISIONED'
+                }
+                )
+            time.sleep(10)
+        except Exception as e:
+            pass        
         
     def emit(self, record):
         try:
@@ -118,9 +130,19 @@ class KinesisLogStreamConsumer():
                 endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
         else:
             self.client = session.client('kinesis')
-            
 
-        
+        try:
+            self.datastream.create_stream(
+                StreamName=os.environ['LOG_STREAMNAME'],
+                ShardCount=1,
+                StreamModeDetails={
+                    'StreamMode': 'PROVISIONED'
+                }
+                )
+            time.sleep(10)
+        except Exception as e:
+            pass        
+                    
         self.stream = self.client.describe_stream(StreamName=os.environ['LOG_STREAMNAME'])
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
@@ -191,6 +213,18 @@ class KinesisStreamProducer():
                 self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
+        
+        try:
+            self.datastream.create_stream(
+                StreamName=stream_name,
+                ShardCount=1,
+                StreamModeDetails={
+                    'StreamMode': 'PROVISIONED'
+                }
+                )
+            time.sleep(10)
+        except Exception as e:
+            pass        
 
     def produce(self, record, partitionkey):    
         _rec = json.dumps(record)            
@@ -214,9 +248,22 @@ class KinesisStreamConsumer():
         print('Initializing stream...')
         session = boto3.Session()
         if 'KINESIS_ENDPOINT_URL' in os.environ:
-            self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+            self.client = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
         else:
-            self.datastream = session.client('kinesis')
+            self.client = session.client('kinesis')
+        
+        try:
+            self.datastream.create_stream(
+                StreamName=self.stream_name,
+                ShardCount=1,
+                StreamModeDetails={
+                    'StreamMode': 'PROVISIONED'
+                }
+                )
+            time.sleep(10)
+        except Exception as e:
+            pass        
+
         self.stream = self.client.describe_stream(StreamName=self.stream_name)
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
